@@ -1,10 +1,10 @@
 from cobra.core.configuration import Configuration
 from cobra.core.dictlist import DictList
-from cobra.core.gene import Gene
+from cobra.core.gene import Gene, GPR
 from cobra.core.metabolite import Metabolite
 from cobra.core.model import Model
 from cobra.core.object import Object
 from cobra.core.reaction import Reaction
 from cobra.core.group import Group
-from cobra.core.solution import Solution, LegacySolution, get_solution
+from cobra.core.solution import Solution, get_solution
 from cobra.core.species import Species
