@@ -1,37 +1,63 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import
+"""Provide functions for I/O in YAML format."""
 
 import io
+from pathlib import Path
+from typing import TYPE_CHECKING, Any, Dict, Optional, Union
 
 from ruamel.yaml.compat import StringIO
 from ruamel.yaml.main import YAML
 
-from cobra.io.dict import model_from_dict, model_to_dict
+from .dict import model_from_dict, model_to_dict
+
+
+if TYPE_CHECKING:
+    from io import TextIOBase
+
+    from cobra import Model
 
 
 YAML_SPEC = "1.2"
 
 
-class MyYAML(YAML):
-    def dump(self, data, stream=None, **kwargs):
-        inefficient = False
+class CobraYAML(YAML):
+    """Define custom subclass for YAML I/O."""
+
+    def dump(
+        self, data: Dict, stream: Optional["TextIOBase"] = None, **kwargs: Any
+    ) -> str:
+        """Dump YAML data.
+
+        Parameters
+        ----------
+        data : dict
+            A dictionary representing the cobra model and its components.
+        stream : TextIOBase, optional
+            A text stream object inheriting from `io.TextIOBase`. If None,
+            `ruamel.yaml.compat.StringIO` is used (default None).
+        **kwargs : Any
+            Keyword arguments passed on to `ruamel.yaml.main.YAML.dump`.
+
+        Returns
+        -------
+        str
+            YAML string representation of `data`.
+
+        """
         if stream is None:
             inefficient = True
             stream = StringIO()
+        else:
+            inefficient = False
         YAML.dump(self, data, stream, **kwargs)
         if inefficient:
             return stream.getvalue()
 
 
-yaml = MyYAML(typ="rt")
+yaml = CobraYAML(typ="rt")
 
 
-def to_yaml(model, sort=False, **kwargs):
-    """
-    Return the model as a YAML document.
-
-    ``kwargs`` are passed on to ``yaml.dump``.
+def to_yaml(model: "Model", sort: bool = False, **kwargs: Any) -> str:
+    """Return the model as a YAML string.
 
     Parameters
     ----------
@@ -39,51 +65,52 @@ def to_yaml(model, sort=False, **kwargs):
         The cobra model to represent.
     sort : bool, optional
         Whether to sort the metabolites, reactions, and genes or maintain the
-        order defined in the model.
+        order defined in the model (default False).
+    **kwargs : Any
+        Keyword arguments passed on to `CobraYAML.dump`.
 
     Returns
     -------
     str
-        String representation of the cobra model as a YAML document.
+        YAML string representation of the cobra model.
 
     See Also
     --------
     save_yaml_model : Write directly to a file.
     ruamel.yaml.dump : Base function.
-    """
 
+    """
     obj = model_to_dict(model, sort=sort)
     obj["version"] = YAML_SPEC
     return yaml.dump(obj, **kwargs)
 
 
-def from_yaml(document):
-    """
-    Load a cobra model from a YAML document.
+def from_yaml(document: str) -> "Model":
+    """Load a cobra model from a YAML string.
 
     Parameters
     ----------
     document : str
-        The YAML document representation of a cobra model.
+        The YAML string representation of a cobra model.
 
     Returns
     -------
     cobra.Model
-        The cobra model as represented in the YAML document.
+        The cobra model as interpreted from the YAML document.
 
     See Also
     --------
     load_yaml_model : Load directly from a file.
+
     """
     content = StringIO(document)
     return model_from_dict(yaml.load(content))
 
 
-def save_yaml_model(model, filename, sort=False, **kwargs):
-    """
-    Write the cobra model to a file in YAML format.
-
-    ``kwargs`` are passed on to ``yaml.dump``.
+def save_yaml_model(
+    model: "Model", filename: str, sort: bool = False, **kwargs: Any
+) -> None:
+    """Write the cobra model to a file in YAML format.
 
     Parameters
     ----------
@@ -94,12 +121,15 @@ def save_yaml_model(model, filename, sort=False, **kwargs):
         written to.
     sort : bool, optional
         Whether to sort the metabolites, reactions, and genes or maintain the
-        order defined in the model.
+        order defined in the model (default False).
+    **kwargs : Any
+        Keyword arguments passed to `CobraYAML.dump`.
 
     See Also
     --------
     to_yaml : Return a string representation.
     ruamel.yaml.dump : Base function.
+
     """
     obj = model_to_dict(model, sort=sort)
     obj["version"] = YAML_SPEC
@@ -110,9 +140,8 @@ def save_yaml_model(model, filename, sort=False, **kwargs):
         yaml.dump(obj, filename, **kwargs)
 
 
-def load_yaml_model(filename):
-    """
-    Load a cobra model from a file in YAML format.
+def load_yaml_model(filename: Union[str, Path]) -> "Model":
+    """Load a cobra model from a file in YAML format.
 
     Parameters
     ----------
@@ -128,8 +157,9 @@ def load_yaml_model(filename):
     See Also
     --------
     from_yaml : Load from a string.
+
     """
-    if isinstance(filename, str):
+    if isinstance(filename, (str, Path)):
         with io.open(filename, "r") as file_handle:
             return model_from_dict(yaml.load(file_handle))
     else:
